<?php

App::uses('AppComponent', 'Controller/Component');

class PreStageComponent extends AppComponent {

	/**
	 * check to see if a user is already logged in
	 * used to skip to the next stage if the user is logged in
	 *
	 * @return bool
	 */
	public function alreadyLoggedIn() {
		if ($this->_controller->Auth->user() !== null) {
			$this->_controller->redirect(
				$this->_controller->calculatePostStageRedirect(
					$this->_controller->activeStage
				)
			);
		}

		return true;
	}

	/**
	 * authorise a user
	 *
	 * @return 	bool
	 */
	public function authUser() {
		if ($this->_controller->Auth->user() !== null) {
			return true;
		}

		return false;
	}

	/**
	 * attempt to load a logged in users addresses
	 *
	 * @return bool
	 */
	public function loadAddresses() {
		if (! CakePlugin::loaded('EvAddressBook')) {
			$this->_controller->Flash->fail('EvAddressBook is not loaded. Cannot retrieve addresses');
			return false;
		}

		if (empty($this->_controller->AddressManager)) {
			$this->_controller->AddressManager = $this->_controller->loadComponent('EvAddressBook.AddressManager');
		}

		$this->_controller->set(
			'addressBook',
			$this->_controller->AddressManager->getAddresses(
				EvClassRegistry::init('EvAddressBook.Address'),
				'EvCore.User',
				$this->_controller->Auth->user('User.id')
			)
		);

		// get the countries for add address dropdown
		$Country = EvClassRegistry::init('EvCountry.Country');
		$this->_controller->set(
			'countries',
			$Country->getForDropDown()
		);

		return true;
	}

	/**
	 * load the shipping plugin and try to auto calculate any shipping
	 *
	 * @return 	bool
	 */
	public function processBasketShipping() {
		return true;
	}

	/**
	 * load EvBasket and load a basket summary
	 * for the user to confirm before payment
	 *
	 * @return 	bool
	 */
	public function loadBasket() {
		if (! CakePlugin::loaded('EvBasket')) {
			$this->_controller->Flash->fail('EvBasket is not loaded. Cannot retrieve basket');
			return false;
		}

		$return = true;

		// load the mbasket manager so we can get the basket
		if (empty($this->_controller->BasketManager)) {
			$this->_controller->BasketManager = $this->_controller->loadComponent('EvBasket.Basket');
		}

		// laod the basket heper incase any of it is in use (it should be!)
		$this->_controller->helpers['Basket'] = array(
			'className' => 'EvBasket.Basket'
		);

		$this->_controller->set(
			'basket',
			$this->_controller->BasketManager->getBasket()
		);

		return $return;
	}

	/**
	 * load the selected address (if any)
	 * and set to template for displaying
	 *
	 * @return bool
	 */
	public function loadSelectedAddresses() {
		if (! CakePlugin::loaded('EvAddressBook')) {
			$this->_controller->Flash->fail('EvAddressBook is not loaded. Cannot retrieve addresses');
			return false;
		}

		// load the address manager component
		if (empty($this->_controller->AddressManager)) {
			$this->_controller->AddressManager = $this->_controller->loadComponent('EvAddressBook.AddressManager');
		}

		// laod the address book helper to aid with formatting of addresses
		$this->_controller->helpers['AddressBook'] = array(
			'className' => 'EvAddressBook.AddressBook'
		);

		// read for the session and process each id
		$addressIds = $this->_controller->Session->read('EvCheckout.address');
		$addresses = array();

		foreach ($addressIds as $key => $addressId) {
			$addresses[$key] = $this->_controller->AddressManager->getAddress(
				EvClassRegistry::init('EvAddressBook.Address'),
				$addressIds[$key]
			);
		}

		$this->_controller->set(
			'selectedAddresses',
			$addresses
		);

		return true;
	}
}
